%**********
% mod_ther.m
%
% Adjustable modeling parameters are:
% Geometry
%  def_nod_pos:	position of default nodes
%  rad_nodes:	number of nodes along the radial length
%  axe_nodes:	number of nodes in depth
%  dr:	radial width
%  dz:	axial depth
%  frad, fcon:	empirical factors which depend of the geometry
% Time and energy pulse
%  dt:	small time increments
%  num_it:	number of iterations
%  source_power:	quantity of energy deposited on the front surface
%  heat_duration:	time interval after which source_power=0
% Thermal parameters
%  rhd:	density / 1000
%  cp:	specific heat / 1000
%  ra_conduct:	radial thermal conductivity	
%  ax_conduct:	axial thermal conductivity
%  kint:	axial thermal conductivity for def_nod_pos
%  ta:	ambient temperature
%  itemp:	initial temperature
%
% Date : 06.06.2000
%
% Last modification: 13.06.2000
%
%**********

function mod_ther


% ***** Initialization

% ***** Geometry
def_nod_pos=12;	% position of default nodes
rad_nodes=20;	% number of nodes along the radial length
axe_nodes=30;	% number of nodes in depth

i=1:rad_nodes;
j=1:axe_nodes;

dr=0.2;	% radial width, cm
dz=0.02;	% axial depth, cm

frad=5.67e-12;	% w/cm^2
fcon=1.0e-3;	% w*cm^2

% ***** Time and energy pulse
dt=0.025;	% small time increments, seconds
num_it=1200;	% number of iterations, 30sec / dt

source_power=1;	% quantity of energy deposited on the front surface, w/cm^2
heat_duration=2;	% time interval after which source_power=0, seconds


% ***** Thermal parameters
rhd=2;	% density / 1000, Kg/1000*m^3
cp=1;	% specific heat / 1000, j/Kg*C*1000
ra_conduct=0.05;	% radial thermal conductivity
ax_conduct=0.01;	% axial thermal conductivity
kint(i)=0.01;	% axial thermal conductivity for def_nod_pos
kint(1:5)=0.00024;      % default:air

ta=273;	% ambient temperature, Kelvin degrees
itemp=double(0.00001);	% initial temperature, Celcius degrees
temp(i,j,1:2)=itemp;


qr(i,j)=double(0.00000001);
qz=qr;

% surfaces crossed by thermal fronts
dslat=2.*pi.*i.*dr.*dz;	% from r to r+dr
dslong=pi.*((i.*dr).^2-((i-1).*dr).^2);	% from z to z+dz 

% increase of temperature on the front surface (nodes in z=1)
temp_var=(source_power*dt)/(rhd*cp*dz);


% ***** Begining of time iteration
tim=0;  % starting time
timlc=log10(0.5);	% 0.5 is the first for which results are displayed

for iter=1:num_it	% num_it iterarions
	tim=tim+dt;
	timl=log10(tim);


% ***** Absorption of thermal power [w/cm^2]
% ***** Application of thermal pulse of heat_duration sec on the surface (Z=1)
if tim<=heat_duration	% for tim>heat_duration, source_power=0
	temp(i,1,1)=temp(i,1,1)+temp_var;
end

temp(i,1,2)=temp(i,1,1);


% ***** Heat propagation through the corps
for ii=1:rad_nodes-1;
for jj=1:axe_nodes-1;

ax_conduct=0.01;
if jj==def_nod_pos
	ax_conduct=kint(ii);
end

% flux along radial and axial directions
qr(ii,jj)=ra_conduct*dslat(ii)*(temp(ii,jj,1)-temp(ii+1,jj,1))/dr;
qz(ii,jj)=ax_conduct*dslong(ii)*(temp(ii,jj,1)-temp(ii,jj+1,1))/dz;

temp(ii,jj,2)=temp(ii,jj,2)-(qr(ii,jj)+qz(ii,jj))*dt/(rhd.*cp.*dslong(ii)*dz);
temp(ii+1,jj,2)=temp(ii+1,jj,2)+qr(ii,jj)*dt/(rhd.*cp.*dslong(ii+1)*dz);
temp(ii,jj+1,2)=temp(ii,jj+1,2)+qz(ii,jj)*dt/(rhd.*cp.*dslong(ii)*dz);

end
end

temp(rad_nodes,:,1)=temp(rad_nodes-1,:,1);
temp(rad_nodes,:,2)=temp(rad_nodes-1,:,2);


% ***** Surface loss calcultation
rad_loss=dslong(i)'.*frad.*((temp(i,1,2)+273).^4-ta^4);	% radiative losses
conv_loss=dslong(i)'.*fcon.*temp(i,1,2);	% convective losses
temp(i,1,2)=temp(i,1,2)-(rad_loss+conv_loss).*dt./(rhd.*cp.*dslong(i)'.*dz);


% ***** Preparation of the last temperature distribution
% ***** for the next iteration
temp(i,j,1)=temp(i,j,2);


% ***** Printout of results
if timl>=timlc
	timlc=timlc+0.2;
	display('time spent (in sec):');
	disp(tim);
	temp(i,j,2)'
end

end	% end of num_it iterations
